@@ -947,6 +947,7 @@ FUNC_NAME(rshift_func_uint64_t_u_u)(uint64_t left, unsigned int right LOG_INDEX)
 
 
 
+#ifdef __STDC__
 
 
 STATIC float
@@ -979,7 +980,11 @@ FUNC_NAME(mul_func_float_f_f)(float sf1, float sf2 LOG_INDEX)
   LOG_EXEC
   return
 #ifndef UNSAFE_FLOAT
+#ifdef __STDC__
     (fabsf((0x1.0p-100f * sf1) * (0x1.0p-28f * sf2)) > (0x1.0p-100f * (0x1.0p-28f * FLT_MAX))) ?
+#else
+    (fabsf((ldexpf(1.0, -100) * sf1) * (0x1.0p-28f * sf2)) > (ldexpf(1.0, -100) * (0x1.0p-28f * FLT_MAX))) ?
+#endif
     UNDEFINED(sf1) :
 #endif
     (sf1 * sf2);
@@ -991,7 +996,11 @@ FUNC_NAME(div_func_float_f_f)(float sf1, float sf2 LOG_INDEX)
   LOG_EXEC
   return
 #ifndef UNSAFE_FLOAT
+#ifdef __STDC__
     ((fabsf(sf2) < 1.0f) && (((sf2 == 0.0f) || (fabsf((0x1.0p-49f * sf1) / (0x1.0p100f * sf2))) > (0x1.0p-100f * (0x1.0p-49f * FLT_MAX))))) ?
+#else
+    ((fabsf(sf2) < 1.0f) && (((sf2 == 0.0f) || (fabsf((0x1.0p-49f * sf1) / (ldexpf(1.0, 100) * sf2))) > (ldexpf(1.0, -100) * (0x1.0p-49f * FLT_MAX))))) ?
+#endif
     UNDEFINED(sf1) :
 #endif
     (sf1 / sf2);
@@ -1030,7 +1039,11 @@ FUNC_NAME(mul_func_double_f_f)(double sf1, double sf2 LOG_INDEX)
   LOG_EXEC
   return
 #ifndef UNSAFE_FLOAT
+#ifdef __STDC__
     (fabs((0x1.0p-100 * sf1) * (0x1.0p-924 * sf2)) > (0x1.0p-100 * (0x1.0p-924 * DBL_MAX))) ?
+#else
+    (fabs((ldexp(1.0, -100) * sf1) * (0x1.0p-924 * sf2)) > (ldexp(1.0, -100) * (0x1.0p-924 * DBL_MAX))) ?
+#endif
     UNDEFINED(sf1) :
 #endif
     (sf1 * sf2);
@@ -1042,13 +1055,137 @@ FUNC_NAME(div_func_double_f_f)(double sf1, double sf2 LOG_INDEX)
   LOG_EXEC
   return
 #ifndef UNSAFE_FLOAT
+#ifdef __STDC__
     ((fabs(sf2) < 1.0) && (((sf2 == 0.0) || (fabs((0x1.0p-974 * sf1) / (0x1.0p100 * sf2))) > (0x1.0p-100 * (0x1.0p-974 * DBL_MAX))))) ?
+#else
+    ((fabs(sf2) < 1.0) && (((sf2 == 0.0) || (fabs((0x1.0p-974 * sf1) / (ldexp(1.0, 100) * sf2))) > (ldexp(1.0, -100) * (0x1.0p-974 * DBL_MAX))))) ?
+#endif
     UNDEFINED(sf1) :
 #endif
     (sf1 / sf2);
 }
 
 
+#else
+
+
+STATIC float
+FUNC_NAME(add_func_float_f_f)(float sf1, float sf2 LOG_INDEX)
+{
+  LOG_EXEC
+  return 
+#ifndef UNSAFE_FLOAT
+    (fabsf((0.5f * sf1) + (0.5f * sf2)) > (0.5f * FLT_MAX)) ? 
+    UNDEFINED(sf1) :
+#endif
+    (sf1 + sf2);
+}
+
+STATIC float
+FUNC_NAME(sub_func_float_f_f)(float sf1, float sf2 LOG_INDEX)
+{
+  LOG_EXEC
+  return 
+#ifndef UNSAFE_FLOAT
+    (fabsf((0.5f * sf1) - (0.5f * sf2)) > (0.5f * FLT_MAX)) ? 
+    UNDEFINED(sf1) :
+#endif
+    (sf1 - sf2);
+}
+
+STATIC float
+FUNC_NAME(mul_func_float_f_f)(float sf1, float sf2 LOG_INDEX)
+{
+  LOG_EXEC
+  return
+#ifndef UNSAFE_FLOAT
+#ifdef __STDC__
+    (fabsf((0x1.0p-100f * sf1) * (ldexpf(1.0, -28) * sf2)) > (0x1.0p-100f * (ldexpf(1.0, -28) * FLT_MAX))) ?
+#else
+    (fabsf((ldexpf(1.0, -100) * sf1) * (ldexpf(1.0, -28) * sf2)) > (ldexpf(1.0, -100) * (ldexpf(1.0, -28) * FLT_MAX))) ?
+#endif
+    UNDEFINED(sf1) :
+#endif
+    (sf1 * sf2);
+}
+
+STATIC float
+FUNC_NAME(div_func_float_f_f)(float sf1, float sf2 LOG_INDEX)
+{
+  LOG_EXEC
+  return
+#ifndef UNSAFE_FLOAT
+#ifdef __STDC__
+    ((fabsf(sf2) < 1.0f) && (((sf2 == 0.0f) || (fabsf((ldexpf(1.0, -49) * sf1) / (0x1.0p100f * sf2))) > (0x1.0p-100f * (ldexpf(1.0, -49) * FLT_MAX))))) ?
+#else
+    ((fabsf(sf2) < 1.0f) && (((sf2 == 0.0f) || (fabsf((ldexpf(1.0, -49) * sf1) / (ldexpf(1.0, 100) * sf2))) > (ldexpf(1.0, -100) * (ldexpf(1.0, -49) * FLT_MAX))))) ?
+#endif
+    UNDEFINED(sf1) :
+#endif
+    (sf1 / sf2);
+}
+
+
+
+
+STATIC double
+FUNC_NAME(add_func_double_f_f)(double sf1, double sf2 LOG_INDEX)
+{
+  LOG_EXEC
+  return 
+#ifndef UNSAFE_FLOAT
+    (fabs((0.5 * sf1) + (0.5 * sf2)) > (0.5 * DBL_MAX)) ? 
+    UNDEFINED(sf1) :
+#endif
+    (sf1 + sf2);
+}
+
+STATIC double
+FUNC_NAME(sub_func_double_f_f)(double sf1, double sf2 LOG_INDEX)
+{
+  LOG_EXEC
+  return 
+#ifndef UNSAFE_FLOAT
+    (fabs((0.5 * sf1) - (0.5 * sf2)) > (0.5 * DBL_MAX)) ? 
+    UNDEFINED(sf1) :
+#endif
+    (sf1 - sf2);
+}
+
+STATIC double
+FUNC_NAME(mul_func_double_f_f)(double sf1, double sf2 LOG_INDEX)
+{
+  LOG_EXEC
+  return
+#ifndef UNSAFE_FLOAT
+#ifdef __STDC__
+    (fabs((0x1.0p-100 * sf1) * (ldexp(1.0, -924) * sf2)) > (0x1.0p-100 * (ldexp(1.0, -924) * DBL_MAX))) ?
+#else
+    (fabs((ldexp(1.0, -100) * sf1) * (ldexp(1.0, -924) * sf2)) > (ldexp(1.0, -100) * (ldexp(1.0, -924) * DBL_MAX))) ?
+#endif
+    UNDEFINED(sf1) :
+#endif
+    (sf1 * sf2);
+}
+
+STATIC double
+FUNC_NAME(div_func_double_f_f)(double sf1, double sf2 LOG_INDEX)
+{
+  LOG_EXEC
+  return
+#ifndef UNSAFE_FLOAT
+#ifdef __STDC__
+    ((fabs(sf2) < 1.0) && (((sf2 == 0.0) || (fabs((ldexp(1.0, -974) * sf1) / (0x1.0p100 * sf2))) > (0x1.0p-100 * (ldexp(1.0, -974) * DBL_MAX))))) ?
+#else
+    ((fabs(sf2) < 1.0) && (((sf2 == 0.0) || (fabs((ldexp(1.0, -974) * sf1) / (ldexp(1.0, 100) * sf2))) > (ldexp(1.0, -100) * (ldexp(1.0, -974) * DBL_MAX))))) ?
+#endif
+    UNDEFINED(sf1) :
+#endif
+    (sf1 / sf2);
+}
+
+
+#endif
 
 
 
